@@ -384,6 +384,7 @@ c_ =  function(x){
 #' @keywords internal
 #' @noRd
 #'
+#' @importFrom dplyr vars
 #'
 #' @param var A tibble
 #' @param attribute An object
@@ -393,4 +394,57 @@ c_ =  function(x){
 add_attr = function(var, attribute, name) {
   attr(var, name) <- attribute
   var
-}
\ No newline at end of file
+}
+
+
+#' @importFrom dplyr distinct_at
+#' @importFrom magrittr equals
+get_specific_annotation_columns = function(.data, .col){
+  
+  
+  # Comply with CRAN NOTES
+  . = NULL
+  
+  # Make col names
+  .col = enquo(.col)
+  
+  # x-annotation df
+  n_x = .data %>% distinct_at(vars(!!.col)) %>% nrow
+  
+  # element wise columns
+  .data %>%
+    select(-!!.col) %>%
+    colnames %>%
+    map(
+      ~
+        .x %>%
+        when(
+          .data %>%
+            distinct_at(vars(!!.col, .x)) %>%
+            nrow() %>%
+            equals(n_x) ~ (.),
+          ~ NULL
+        )
+    ) %>%
+    
+    # Drop NULL
+    {	(.)[lengths((.)) != 0]	} %>%
+    unlist
+  
+}
+
+subset_tidyseurat = 		function(.data,	 .column)	{
+  # Make col names
+  .column = enquo(.column)
+  
+  # Check if column present
+  if(quo_names(.column) %in% colnames(.data) %>% all %>% `!`)
+    stop("nanny says: some of the .column specified do not exist in the input data frame.")
+  
+  .data %>%
+    
+    # Selecting the right columns
+    select(	!!.column,	get_specific_annotation_columns(.data, !!.column)	) %>%
+    distinct()
+  
+}
